---
title: <span class="badge object-type-scalar"></span> CubicFeetPerSecond
---
# <span class="badge object-type-scalar"></span> CubicFeetPerSecond

Flow: Cubic feet/sec (cfs)

## Definition

```python
# Flow: Cubic feet/sec (cfs)
CubicFeetPerSecond: typing.Literal["flowcms"] = "flowcms"
```
